@@ -106,7 +106,6 @@ def initConf(self, profile, REQUEST):
         self.importConfPackage(filename,REQUEST,createIfNotExists)
       elif filename.find('.xml') > 0:
         self.importConf(filename,REQUEST,createIfNotExists)
-      self.synchronizeObjAttrs()
 
 
 # ------------------------------------------------------------------------------
@@ -165,7 +164,6 @@ class ConfManager(
       for f in files:
         if not f.get('isdir'):
           self.importConf(f,REQUEST,createIfNotExists)
-      self.synchronizeObjAttrs()
 
 
     # --------------------------------------------------------------------------
@@ -205,6 +203,7 @@ class ConfManager(
       elif filename.find('.textfmt.') > 0:
         self.format_manager.importTextformatXml(xmlfile, REQUEST, createIfNotExists)
       xmlfile.close()
+      self.synchronizeObjAttrs()
       return message
 
 
@@ -685,6 +684,12 @@ class ConfManager(
     ###
     ############################################################################
     """
+    
+    def get_zmi_logo(self, REQUEST=None, RESPONSE=None):
+      """ get_zmi_logo """
+      if self.zmi_logo is not None:
+        return self.zmi_logo.data
+      return ''
 
     ############################################################################
     #  ConfManager.manage_customizeDesign: 
@@ -766,7 +771,7 @@ class ConfManager(
       # -------
       elif btn == self.getZMILangStr('BTN_UPLOAD'):
         #-- ZMI Logo.
-        self.zmi_logo = Image(id='logo', title='', file='')
+        self.zmi_logo = Image(id='zmi_logo', title='', file='')
         self.zmi_logo.manage_upload(REQUEST['file'],REQUEST)
         message = self.getZMILangStr('MSG_CHANGED')
       
