@@ -8,7 +8,7 @@ $(function(){
 	$ZMI.setCursorWait("BO bootstrap.plugin.zmi");
 
 	// Sitemap
-	var $icon_sitemap = $('#zmi-header a '+$ZMI.icon_selector("icon-sitemap"));
+	var $icon_sitemap = $('.zmi header a '+$ZMI.icon_selector("icon-sitemap"));
 	if ($icon_sitemap.length > 0) {
 		var $a = $icon_sitemap.closest("a");
 		if (self.window.parent.frames.length > 1 && typeof self.window.parent != "undefined" && (self.window.parent.location+"").indexOf('dtpref_sitemap=1') > 0) {
@@ -45,7 +45,7 @@ $(function(){
 			if ($("span.input-group-addon",this).length==0) {
 				$(this).addClass("input-group");
 				if ($textarea.attr('data-style')) {
-					$(this).append('<span class="input-group-addon btn btn-default" title="Click for Code Popup or Dbl-Click for Zope Editor!" style="' + $textarea.attr('data-style') + '">   </span>');
+					$(this).append('<span class="input-group-addon btn btn-default" title="Click for Code Popup or Dbl-Click for Native Editor!" style="' + $textarea.attr('data-style') + '">   </span>');
 				} else {
 					$(this).append('<span class="input-group-addon btn btn-default">...</span>');
 				};
@@ -225,18 +225,27 @@ $(function(){
 				var $button = $('button.btn.split-right.dropdown-toggle',this);
 				$button.append($ZMI.icon("icon-chevron-down"));
 				$($ZMI.icon_selector("icon-chevron-down"),$button).hide();
+				if ($(this).parents("li.zmi-item:first").hasClass("zmi-nochildren")) {
+					$ZMI.actionList.over(this,"each",evt);
+				}
 			})
 		.focus( function(evt) {
-				$ZMI.actionList.over(this,"focus",evt);
+				if (!$(this).parents("li.zmi-item:first").hasClass("zmi-nochildren")) {
+					$ZMI.actionList.over(this,"focus",evt);
+				}
 			})
 		.hover( function(evt) {
-				$ZMI.actionList.over(this,"mouseover",evt);
+				if (!$(this).parents("li.zmi-item:first").hasClass("zmi-nochildren")) {
+					$ZMI.actionList.over(this,"mouseover",evt);
+				}
 				var $button = $('button.btn.split-right.dropdown-toggle',this);
 				$(':not('+$ZMI.icon_selector("icon-chevron-down")+')',$button).hide();
 				$($ZMI.icon_selector("icon-chevron-down"),$button).show();
 			},
 			function(evt) {
-				$ZMI.actionList.out(this,"mouseout");
+				if (!$(this).parents("li.zmi-item:first").hasClass("zmi-nochildren")) {
+					$ZMI.actionList.out(this,"mouseout");
+				}
 				var $button = $('button.btn.split-right.dropdown-toggle',this);
 				$($ZMI.icon_selector("icon-chevron-down"),$button).hide();
 				$(':not('+$ZMI.icon_selector("icon-chevron-down")+')',$button).show();
@@ -273,11 +282,12 @@ function zmiUnlockForm(form_id) {
  * Init input_fields
  */ 
 ZMI.prototype.initInputFields = function(container) {
-	$ZMI.setCursorWait("BO zmiInitInputFields["+$('form.form-horizontal:not(.form-initialized)',container).length+"]");
-	$('form.form-horizontal:not(.form-initialized)',container)
+	$ZMI.setCursorWait("BO zmiInitInputFields["+$('form:not(.form-initialized)',container).length+"]");
+	$('form:not(.form-initialized)',container)
 		.submit(function() {
-				$ZMI.writeDebug("form.form-horizontal:not(.form-initialized): submit");
+				$ZMI.writeDebug("form:not(.form-initialized): submit");
 				var b = true;
+				var context = this;
 				// Button
 				if(self.btnClicked==getZMILangStr("BTN_BACK") ||
 						self.btnClicked==getZMILangStr("BTN_CANCEL")) {
@@ -315,9 +325,12 @@ ZMI.prototype.initInputFields = function(container) {
 								isBlank = $control.val().basicTrim().length==0;
 								if (isBlank && nodeType=="file") {
 									var name = $control.attr("name");
-									var exists = $('input[name=exists_'+forName+']:hidden',$controlGroup).val();
-									$ZMI.writeDebug('submit: exists='+exists);
+									var exists = $('input[name="exists_'+forName+'"]:hidden',$controlGroup).val();
+									$ZMI.writeDebug('submit: exists_'+forName+'='+exists);
 									isBlank = !(exists=='True');
+									var generate_preview = $('input[name="generate_preview_'+forName.replace(/_/,'hires_')+':int"]:checked',context).val();
+									$ZMI.writeDebug('submit: generate_preview_'+forName.replace(/_/,'hires_')+':int='+generate_preview);
+									isBlank &= !(generate_preview=='1');
 								}
 							}
 							else if (nodeName=="select") {
@@ -333,6 +346,16 @@ ZMI.prototype.initInputFields = function(container) {
 								}
 								b = false;
 							}
+							else {
+								var dataExclude = $(this).attr("data-exclude");
+								if (typeof dataExclude != "undefined") {
+									var excludeList = dataExclude.split(",");
+									var v = $control.val();
+									if ($.inArray(v,excludeList)) {
+										$controlGroup.addClass("has-error");
+									}
+								}
+							}
 						}
 					});
 				// Lock
@@ -374,7 +397,7 @@ ZMI.prototype.initInputFields = function(container) {
 			}
 			$(this).addClass('form-initialized');
 			// Button-Clicked
-			$ZMI.writeDebug("BO zmiInitInputFields: submit["+$('input[type="submit"],button[type="submit"]',context).length+"]");
+			$ZMI.writeDebug("zmiInitInputFields: submit["+$('input[type="submit"],button[type="submit"]',context).length+"]");
 			$('input[type="submit"],button[type="submit"]',context)
 				.click(function() {
 						self.btnClicked = $(this).attr("value");
